############
Legal Notice
############

*******
License
*******

`MIT License <https://opensource.org/licenses/MIT>`_

Copyright (C) 2016-2020 Lara Welder, Theresa Groß, Leander Kotzur, Robin Beer, Henrik Büsing, Dilara Caglayan, Heidi Heinrichs,
Maximilian Hoffmann, Timo Kannengießer, Kevin Knosala, Felix Kullmann, Stefan Kraus, Jochen Linßen, Lars Nolting, Jan Priesmann,
Bismark Singh, Andreas Smolenko, Chloi Syranidou, Johannes Thürauf, Michael Zier, Martin Robinius, Detlef Stolten

***************
Acknowledgement
***************

This work was supported by the Helmholtz Association under the Joint Initiative `"Energy System 2050 A Contribution of
the Research Field Energy" <https://www.helmholtz.de/en/research/energy/energy_system_2050/>`_.

.. image:: https://www.helmholtz.de/fileadmin/user_upload/05_aktuelles/Marke_Design/logos/HG_LOGO_S_ENG_RGB.jpg
    :target: https://www.helmholtz.de/en/
    :width: 200px
    :alt: Helmholtz Logo
    :align: center